@@ -17,7 +17,6 @@ if sys.version_info >= (3, 8):
     from typing import Literal
 else:
     from typing_extensions import Literal
-
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -84,6 +83,7 @@ __all__ = (
     "TaggedResourceTypeDef",
     "UpdateTargetTypeDef",
     "UsageLimitTypeDef",
+    "VpcEndpointTypeDef",
     "VpcSecurityGroupMembershipTypeDef",
     "AcceptReservedNodeExchangeOutputMessageTypeDef",
     "AccountAttributeListTypeDef",
@@ -330,6 +330,8 @@ ClusterTypeDef = TypedDict(
         "ExpectedNextSnapshotScheduleTimeStatus": str,
         "NextMaintenanceWindowStartTime": datetime,
         "ResizeInfo": "ResizeInfoTypeDef",
+        "AvailabilityZoneRelocationStatus": str,
+        "ClusterNamespaceArn": str,
     },
     total=False,
 )
@@ -384,7 +386,11 @@ ElasticIpStatusTypeDef = TypedDict(
     "ElasticIpStatusTypeDef", {"ElasticIp": str, "Status": str}, total=False
 )
 
-EndpointTypeDef = TypedDict("EndpointTypeDef", {"Address": str, "Port": int}, total=False)
+EndpointTypeDef = TypedDict(
+    "EndpointTypeDef",
+    {"Address": str, "Port": int, "VpcEndpoints": List["VpcEndpointTypeDef"]},
+    total=False,
+)
 
 EventCategoriesMapTypeDef = TypedDict(
     "EventCategoriesMapTypeDef",
@@ -688,6 +694,7 @@ SnapshotTypeDef = TypedDict(
         "ClusterCreateTime": datetime,
         "MasterUsername": str,
         "ClusterVersion": str,
+        "EngineFullVersion": str,
         "SnapshotType": str,
         "NodeType": str,
         "NumberOfNodes": int,
@@ -786,6 +793,8 @@ UsageLimitTypeDef = TypedDict(
     total=False,
 )
 
+VpcEndpointTypeDef = TypedDict("VpcEndpointTypeDef", {"VpcEndpointId": str}, total=False)
+
 VpcSecurityGroupMembershipTypeDef = TypedDict(
     "VpcSecurityGroupMembershipTypeDef", {"VpcSecurityGroupId": str, "Status": str}, total=False
 )
